@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2020-04-16'; # DATE
-our $VERSION = '0.871'; # VERSION
+our $DATE = '2020-04-27'; # DATE
+our $VERSION = '0.872'; # VERSION
 
 use 5.010;
 use Log::ger;
@@ -141,19 +141,31 @@ sub gen_doc_section_arguments {
     } elsif ($aa eq 'hashref') {
         $aplt = '(\%args)';
     } elsif ($aa =~ /\Aarray(ref)?\z/) {
+        my @pos_args;
+        my @named_args;
+        my $all_named_args_are_optional = 1;
+        for (sort { ($args_p->{$a}{pos} // 9999) <=>
+                        ($args_p->{$b}{pos} // 9999) } keys %$args_p) {
+            if (defined $args_p->{$_}{pos}) {
+                push @pos_args, $_;
+            } else {
+                push @named_args, $_;
+                $all_named_args_are_optional = 0 if $args_p->{$_}{req};
+            }
+        }
+
         $aplt = join(
             '',
             '(',
             ($aa eq 'arrayref' ? '[' : ''),
-            join(', ',
-                 map {
-                     my $var = $_; $var =~ s/[^A-Za-z0-9_]+/_/g;
-                     "\$$var" . (($args_p->{$_}{slurpy} // $args_p->{$_}{greedy}) ? ', ...' : '');
-                 }
-                     sort {
-                         ($args_p->{$a}{pos} // 9999) <=>
-                             ($args_p->{$b}{pos} // 9999)
-                         } keys %$args_p),
+            join(
+                ', ',
+                (@named_args ? ($all_named_args_are_optional ? (" [ \\\%optional_named_args ] ") : ("\\\%named_args")) : ()),
+                map {
+                    my $var = $_; $var =~ s/[^A-Za-z0-9_]+/_/g;
+                    "\$$var" . (($args_p->{$_}{slurpy} // $args_p->{$_}{greedy}) ? ', ...' : '');
+                } @pos_args,
+            ),
             ($aa eq 'arrayref' ? ']' : ''),
             ')'
         );
@@ -228,7 +240,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.871 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2020-04-16.
+This document describes version 0.872 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2020-04-27.
 
 =for Pod::Coverage .+
 
